@@ -235,7 +235,7 @@ class ProctorservApi(object):
   def convert_times_to_integer(self, time):
     """ converts a datetime object to seconds past epoch """
     time_tuple = time.utctimetuple()
-    time = str(calendar.timegm(time_tuple))
+    time = int(calendar.timegm(time_tuple))
     
     return time
 
@@ -318,4 +318,3 @@ class ProctorservApi(object):
 
 
 
-
